.BG
.FN persp.hazcov
.TL
Perspective plots of hazard estimates
.DN
Function to create perspective plots using output from hazcov()
.CS
persp.hazcov(formula, object, given.values, wt, xlab, ylab, zlab, ...)
.RA
.AG formula
Model formula of the form resp~cov1*cov2, where if resp begins with an
"l" or "L" log ratios will be plotted, otherwise hazards will be, and
`cov1' and `cov2' specify the x and y covariates in the plot.  These
covariates must be names corresponding to terms in `object$midp'
(including Time), and must be numeric variables.
.AG object
An object of class `"hazcov"' (output from function `hazcov()')
.OA
.AG given.values
A list giving values for covariates (including Time) in the model but not in
formula.  If specified, estimates will be calculated at these values.  Names
of the components in the list must match the names in `object$midp'.
.AG wt
(length=ntg) optional vector of prior relative risks.  hazards on time
interval `i' are multiplied by `wt[i]'.
.AG xlab,ylab,zlab
axis labels in the plot.
.AG ...
additional arguments passed to `persp()'
.RT
returns a list giving the values used for covariates not in formula.
.SE
Creates a perspective plot on the current device.  
.DT
The values used for covariates not in formula are the median of the
components of `object$midp' for numeric 
variables, and the first component of the factor levels in the
component of `z$midp' for factors.  If `given.values' are specified, only one
value each should be given. 
.SA
`hazcov',  `plot.hazcov',  `coplot.hazcov'
.EX
z <- hazcov(cbind(TTR,Fail.Ind)~ER+Log.Nodes+Tumor.Size,data=jd,span=.20)
persp.hazcov(Hazard.Rate~Time*Log.Nodes,z,given.values=
  list(ER=as.factor(c("Pos")),Tumor.Size=3))
persp.hazcov(Hazard.Rate~Time*Log.Nodes,z,given.values=
  list(ER=as.factor(c("Neg")),Tumor.Size=3))
.KW survival
.KW hazcov
.WR
